==> dif-core-2.1.9-1-20151124.172801-2-sources.jar: pt/digitalis/dif/dem/annotations/parameter/Rule.java <==
/** 2009, Digitalis Informatica. All rights reserved.
 *
 * Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1
 * 2780-666 Paco de Arcos
 * Telefone: (351) 21 4408990
 * Fax: (351) 21 4408999
 * http://www.digitalis.pt
 */

package pt.digitalis.dif.dem.annotations.parameter;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import pt.digitalis.dif.dem.annotations.AnnotationTags;
import pt.digitalis.dif.dem.annotations.metaannotations.BindToPrimary;
import pt.digitalis.dif.dem.objects.parameters.rules.ParameterRuleAction;


/**
 * Rule association for a given parameter.
 *
 *
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created Mar 31, 2009
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
@BindToPrimary( { "pt.digitalis.dif.dem.annotations.parameter.Parameter" })
public @interface Rule {

    /** The ID of the corresponding rule. Any contributed parameter rule id. */
    String ruleId();

    /** The parameter list. Comma separated if more than one */
    String parameters();

    /** The value to compare */
    String value() default AnnotationTags.NONE;

    /** The first value of the interval to validate */
    String first() default AnnotationTags.NONE;

    /** The last value of the interval to validate */
    String last() default AnnotationTags.NONE;

    /** the action to perform upon not validating */
    ParameterRuleAction action() default ParameterRuleAction.HIDE;


}

==> dif-core-2.6.0-sources.jar: pt/digitalis/dif/dem/annotations/parameter/Rule.java <==
/**
 * 2009, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.dem.annotations.parameter;

import pt.digitalis.dif.dem.annotations.AnnotationTags;
import pt.digitalis.dif.dem.annotations.metaannotations.BindToPrimary;
import pt.digitalis.dif.dem.objects.parameters.rules.ParameterRuleAction;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Rule association for a given parameter.
 *
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created Mar 31, 2009
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
@BindToPrimary({"pt.digitalis.dif.dem.annotations.parameter.Parameter"})
public @interface Rule
{

    /** the action to perform upon not validating */
    ParameterRuleAction action() default ParameterRuleAction.HIDE;

    /** The first value of the interval to validate */
    String first() default AnnotationTags.NONE;

    /** The last value of the interval to validate */
    String last() default AnnotationTags.NONE;

    /** The parameter list. Comma separated if more than one */
    String parameters();

    /** The ID of the corresponding rule. Any contributed parameter rule id. */
    String ruleId();

    /** The value to compare */
    String value() default AnnotationTags.NONE;
}
